@@ -24,9 +24,8 @@
 
 #include <stdio.h>
 #include <sys/types.h>
-#include <getopt.h>
 #include "system.h"
-#include "checkopt.h"
+#include "#NAME#-opt.h"
 
 char *xmalloc ();
 char *xrealloc ();
@@ -43,7 +42,7 @@ main (int argc, char **argv)
     if ((argc < ARGC_MIN) || (argc > ARGC_MAX)) 
       {
 	fprintf( stderr, "%s ERROR:  remaining args (%d) "
-		 "out of range\n", myprogOptions.pzProgName,
+		 "out of range\n", #NAME#Options.pzProgName,
 		 argc );
 	
 	USAGE( EXIT_FAILURE );
@@ -59,6 +58,5 @@ main (int argc, char **argv)
 
   /* do the work */
 
-  exit (0);
+  return EXIT_SUCCESS;
 }
-
