@@ -242,7 +242,7 @@ static void
 usage (int status)
 {
   printf (_("%s - \
-#DESCRIPTION#\n"), program_name);
+#DESCRIPTIONC#\n"), program_name);
   printf (_("Usage: %s [OPTION]... [FILE]...\n"), program_name);
   printf (_("\
 Options:\n\
